@@ -3,8 +3,7 @@
 
 
 
-#line 21 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
-/* Copyright (C) 1995-2023 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2024 Free Software Foundation, Inc.
 
    This file is part of the GNU Binutils.
 
@@ -52,9 +51,7 @@
 #include "ldctor.h"
 #include "ldbuildid.h"
 #include "coff/internal.h"
-#line 75 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
 #include "pdb.h"
-#line 81 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
 
 /* FIXME: See bfd/peXXigen.c for why we include an architecture specific
    header in generic PE code.  */
@@ -168,7 +165,6 @@ gldi386pe_before_parse (void)
 #ifdef DLL_SUPPORT
   input_flags.dynamic = true;
   config.has_shared = 1;
-#line 226 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
   link_info.pei386_auto_import = 1;
   /* Use by default version.  */
   link_info.pei386_runtime_pseudo_reloc = DEFAULT_PSEUDO_RELOC_VERSION;
@@ -1280,7 +1276,7 @@ pecoff_checksum_contents (bfd *abfd,
       if (bfd_seek (abfd, filepos, SEEK_SET) != 0)
 	return 0;
 
-      status = bfd_bread (&b, (bfd_size_type) 1, abfd);
+      status = bfd_read (&b, 1, abfd);
       if (status < 1)
 	{
 	  break;
@@ -1371,7 +1367,7 @@ write_build_id (bfd *abfd)
   if (bfd_seek (abfd, asec->filepos + link_order->offset, SEEK_SET) != 0)
     return 0;
 
-  if (bfd_bwrite (contents, sizeof (*ext), abfd) != sizeof (*ext))
+  if (bfd_write (contents, sizeof (*ext), abfd) != sizeof (*ext))
     return 0;
 
 #ifdef PDB_H
@@ -2387,8 +2383,8 @@ gldi386pe_open_dynamic_archive
 			    search->name and the start of the format string.  */
 			 + 2);
 
-  sprintf (full_string, "%s/", search->name);
-  base_string = full_string + strlen (full_string);
+  base_string = stpcpy (full_string, search->name);
+  *base_string++ = '/';
 
   for (i = 0; libname_fmt[i].format; i++)
     {
@@ -2427,7 +2423,6 @@ gldi386pe_find_potential_libraries
 
 static char *
 gldi386pe_get_script (int *isfile)
-#line 2542 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
 {
   *isfile = 1;
 
@@ -2439,15 +2434,12 @@ gldi386pe_get_script (int *isfile)
     return "ldscripts/i386pe.xbn";
   else if (!config.magic_demand_paged)
     return "ldscripts/i386pe.xn";
-#line 2556 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
   else if (link_info.pei386_auto_import == 1
 	   && (MERGE_RDATA_V2 || link_info.pei386_runtime_pseudo_reloc != 2))
     return "ldscripts/i386pe.xa";
-#line 2562 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/pe.em"
   else
     return "ldscripts/i386pe.x";
 }
-#line 4 "/mnt/share/cygpkgs/binutils/binutils.x86_64/src/binutils-2.41/ld/emultempl/emulation.em"
 
 struct ld_emulation_xfer_struct ld_i386pe_emulation =
 {
